@@ -9,7 +9,7 @@ from colorama import Fore
 from colorama import Style
 
 from . import dlpx_exceptions
-from . import dx_logging
+from . import dx_logging as log
 from dxi._lib import util
 
 
@@ -31,7 +31,7 @@ def run_job(main_func, dx_obj, engine="default", single_thread=True):
     threads = []
     # if engine ="all", run against every engine in config_file
     if engine == "all":
-        dx_logging.print_info(f"Executing on all Delphix Engines")
+        log.print_info(f"Executing on all Delphix Engines")
         try:
             for delphix_ddp in dx_obj.dlpx_ddps:
                 t = main_func(
@@ -43,7 +43,7 @@ def run_job(main_func, dx_obj, engine="default", single_thread=True):
                 # processing of operations across multiple engines
                 time.sleep(1)
         except dlpx_exceptions.DlpxException as err:
-            dx_logging.print_exception(f"Error encountered in run_job():{err}")
+            log.print_exception(f"Error encountered in run_job():{err}")
     elif engine == "default":
         try:
             for delphix_ddp in dx_obj.dlpx_ddps.keys():
@@ -52,7 +52,7 @@ def run_job(main_func, dx_obj, engine="default", single_thread=True):
                     dx_obj_default.dlpx_ddps = {
                         delphix_ddp: dx_obj.dlpx_ddps[delphix_ddp]
                     }
-                    dx_logging.print_info(
+                    log.print_info(
                         "Executing on the default Delphix Engine"
                     )
                     t = main_func(
@@ -68,7 +68,7 @@ def run_job(main_func, dx_obj, engine="default", single_thread=True):
             engine_ref = dx_obj.dlpx_ddps[engine]
             t = main_func(engine_ref, dx_obj, single_thread)
             threads.append(t)
-            dx_logging.print_info(
+            log.print_info(
                 f"Executing on Delphix Engine: " f'{engine_ref["hostname"]}'
             )
         except (exceptions.RequestError, KeyError):
@@ -111,7 +111,7 @@ def run_job_mt(
     threads = []
     # if engine ="all", run against every engine in config_file
     if engine == "all":
-        dx_logging.print_debug(f"Executing on all configured Delphix Engines.")
+        log.print_debug(f"Executing on all configured Delphix Engines.")
         try:
             for delphix_ddp in dx_obj.dlpx_ddps:
                 engine_ref = dx_obj.dlpx_ddps[delphix_ddp]
@@ -123,7 +123,7 @@ def run_job_mt(
                 threads.append(t)
                 time.sleep(2)
         except dlpx_exceptions.DlpxException as err:
-            dx_logging.print_exception(
+            log.print_exception(
                 f"Error encountered in run_job():\n{err}"
             )
             raise err
@@ -138,7 +138,7 @@ def run_job_mt(
                     }
                     engine_ref = dx_obj.dlpx_ddps[delphix_ddp]
                     dx_obj.jobs[engine_ref["ip_address"]] = []
-                    dx_logging.print_debug(
+                    log.print_debug(
                         f"Running on Delphix Engine {engine_ref['hostname']}"
                     )
                     t = _get_thread(
@@ -151,9 +151,10 @@ def run_job_mt(
                     threads.append(t)
                     break
         except TypeError as err:
+            log.print_exception(f"Error in run_job: {err}")
             raise dlpx_exceptions.DlpxException(f"Error in run_job: {err}")
         except (dlpx_exceptions.DlpxException) as e:
-            dx_logging.print_exception(f"Error in run_job():\n{e}")
+            log.print_exception(f"Error in run_job():\n{e}")
             raise e
     else:
         # Test to see if the engine exists in config_file
@@ -164,7 +165,7 @@ def run_job_mt(
                 main_func, engine_ref, dx_obj, single_thread, helper_ref
             )
             threads.append(t)
-            dx_logging.print_debug(
+            log.print_debug(
                 f"Running on Delphix Engine {engine_ref['hostname']}"
             )
         except (exceptions.RequestError, KeyError):
@@ -173,7 +174,6 @@ def run_job_mt(
                 f"check your input and try again."
             )
         except (dlpx_exceptions.DlpxException) as e:
-            dx_logging.print_exception(f"Error in run_job():\n{e}")
             raise e
     if engine is None:
         raise dlpx_exceptions.DlpxException(
@@ -202,11 +202,11 @@ def track_running_jobs(
     if engine["ip_address"] in dx_obj.jobs:
         engine_running_jobs = dx_obj.jobs[engine["ip_address"]]
     if not engine_running_jobs:
-        dx_logging.print_debug(
+        log.print_debug(
             f'No running jobs on engine : {engine["hostname"]}'
         )
     else:
-        dx_logging.print_info(f'Tracking running jobs on {engine["hostname"]}')
+        log.print_info(f'Tracking running jobs on {engine["hostname"]}')
     while engine_running_jobs:
         for j in engine_running_jobs:
             job_obj = job.get(dx_obj.server_session, j)
@@ -216,9 +216,9 @@ def track_running_jobs(
             elif job_obj.job_state in ["CANCELED", "FAILED"]:
                 err_msg = extract_failure_message(job_obj, engine["hostname"])
                 engine_running_jobs.remove(j)
-                dx_logging.print_exception(f"{engine['hostname']}:{job_obj.reference} FAILED or was CANCELLED "
+                log.print_exception(f"{engine['hostname']}:{job_obj.reference} FAILED or was CANCELLED "
                       f"due to an error.", stdout= False)
-                dx_logging.print_exception(f"{err_msg}")
+                log.print_exception(f"{err_msg}")
                 print(f"\t{engine['hostname']}:{Fore.RED}{job_obj.reference}:{job_obj.percent_complete}% {Style.RESET_ALL}")
                 failures[0] = True
             elif job_obj.job_state in "RUNNING":
@@ -237,7 +237,8 @@ def extract_failure_message(jobobj, engine_ref):
                 engine_name=engine_ref
             )
         return err_msg
-    except (Exception) as err:
+    except Exception as err:
+        log.print_exception(err)
         return
 
 
@@ -252,12 +253,12 @@ def find_job_state(engine, dx_obj, poll=5):
     :return:
     """
     # get all the jobs, then inspect them
-    dx_logging.print_debug(f"Checking running jobs state")
+    log.print_debug(f"Checking running jobs state")
     i = 0
     for j in dx_obj.jobs.keys():
         print(len(dx_obj.jobs), j)
         job_obj = job.get(dx_obj.server_session, dx_obj.jobs[j])
-        dx_logging.print_debug(
+        log.print_debug(
             f'{engine["ip_address"]}: Running job: ' f"{job_obj.job_state}"
         )
         if job_obj.job_state in ["CANCELED", "COMPLETED", "FAILED"]:
@@ -270,13 +271,13 @@ def find_job_state(engine, dx_obj, poll=5):
             # If the job is in a running state, increment the
             # running job count.
             i += 1
-        dx_logging.print_debug(f'{engine["ip_address"]}: {i} jobs running.')
+        log.print_debug(f'{engine["ip_address"]}: {i} jobs running.')
         # If we have running jobs, pause before repeating the
         # checks.
         if dx_obj.jobs:
             time.sleep(poll)
         else:
-            dx_logging.print_debug(f"No jobs running")
+            log.print_debug(f"No jobs running")
             break
 
 
@@ -293,12 +294,12 @@ def find_job_state_by_jobid(engine, dx_obj, job_id, poll=20):
     """
     # get the job object
     job_obj = job.get(dx_obj.server_session, job_id)
-    dx_logging.print_debug(job_obj)
-    dx_logging.print_debug(f" Waiting for : {job_id} to finish")
+    log.print_debug(job_obj)
+    log.print_debug(f" Waiting for : {job_id} to finish")
     while job_obj.job_state == "RUNNING":
         time.sleep(poll)
         job_obj = job.get(dx_obj.server_session, job_id)
-    dx_logging.print_debug(
+    log.print_debug(
         f"Job: {job_id} completed with status: {job_obj.job_state}"
     )
     return job_obj.job_state
