@@ -10,6 +10,7 @@ from delphixpy.v1_10_2.web import user
 from delphixpy.v1_10_2.web import vo
 from dxi._lib import dx_logging
 from dxi._lib import get_references
+from dxi._lib import dxi_constants as const
 from dxi._lib import run_job
 from dxi._lib.dlpx_exceptions import DXIException
 from dxi._lib.run_async import run_async
@@ -18,6 +19,7 @@ from dxi.dxi_tool_base import DXIBase
 from tabulate import tabulate
 
 
+
 class DXIContainerConstants(object):
     """
     Define constants for Self Service Container class and CLI usage
@@ -30,12 +32,20 @@ class DXIContainerConstants(object):
     LOG_FILE_PATH = DXIConfigConstantsHelper().get_logdir()
     BCK_FILE = None
     USE_BACKUP = False
-    USE_BACKUP = False
     CREATE_BACKUP = False
     ENGINE_ID = "default"
     NAME = None
     GROUP = None
     PARALLEL = 5
+    LIST_HEADER = [
+        "Engine",
+        "Container Name",
+        "Active Branch",
+        "Owner",
+        "Reference",
+        "Template",
+        "Last Updated",
+    ]
 
 
 class DXIContainer(DXIBase):
@@ -83,13 +93,20 @@ class DXIContainer(DXIBase):
 
     def list(self):
         """
-        :return: Give all containers on a given engine
-        :rtype: `list`
+        List all Self-Service containers.
+        Returns:
+            container_list: A list of containers on the Delphix Engines.
+        Raises:
+            Does not raise an exception. If an exception is encountered,
+            returns a boolean False.
         """
+        self.print_list = []
+        self.container_list = []
         try:
             dx_logging.print_info(f"Running dxi container list.")
             self._execute_operation(self.__list_container_helper)
-            return True
+            self._display_list(self.print_list,DXIContainerConstants.LIST_HEADER)
+            return self.container_list
         except Exception:
             return False
 
@@ -109,21 +126,11 @@ class DXIContainer(DXIBase):
         try:
             dlpx_obj = self._initialize_session()
             self._setup_dlpx_session(dlpx_obj, engine_ref)
-            print_list = []
             with dlpx_obj.job_mode(single_thread):
-                container_list = []
-                header = [
-                    "Name",
-                    "Active Branch",
-                    "Owner",
-                    "Reference",
-                    "Template",
-                    "Last Updated",
-                ]
                 ss_containers = selfservice.container.get_all(
                     dlpx_obj.server_session
                 )
-                dx_logging.print_debug(header)
+                dx_logging.print_debug(DXIContainerConstants.LIST_HEADER)
                 for ss_container in ss_containers:
                     last_updated = get_references.convert_timestamp(
                         dlpx_obj.server_session, ss_container.last_updated[:-5]
@@ -133,8 +140,9 @@ class DXIContainer(DXIBase):
                         f"{ss_container.owner}, {ss_container.reference},"
                         f"{ss_container.template}, {last_updated}"
                     )
-                    print_list.append(
+                    self.print_list.append(
                         [
+                            engine_ref["hostname"],
                             ss_container.name,
                             ss_container.active_branch,
                             ss_container.owner,
@@ -143,11 +151,12 @@ class DXIContainer(DXIBase):
                             last_updated,
                         ]
                     )
-                    container_list.append(
+                    self.container_list.append(
                         dict(
                             zip(
-                                header,
+                                DXIContainerConstants.LIST_HEADER,
                                 [
+                                    engine_ref["hostname"],
                                     ss_container.name,
                                     ss_container.active_branch,
                                     ss_container.owner,
@@ -158,12 +167,6 @@ class DXIContainer(DXIBase):
                             )
                         )
                     )
-            #       self._add_last_job_to_track(dlpx_obj)
-            # run_job.track_running_jobs(
-            #     engine_ref, dlpx_obj, poll=self.poll, failures=self.failures
-            # )
-            print(tabulate(print_list, headers=header, tablefmt="github"))
-            return container_list
         except DXIException as err:
             dx_logging.print_exception(err)
             self.failures[0] = True
@@ -262,7 +265,7 @@ class DXIContainer(DXIBase):
             )
             self.failures[0] = True
 
-    def delete(self, container_name, keep_vdbs=False):
+    def delete(self, container_name, delete_vdbs=False, keep_vdbs=True):
         """
         :param container_name: Name of the SS Container
         :type container_name: `str`
@@ -273,7 +276,8 @@ class DXIContainer(DXIBase):
         :rtype: `bool`
         """
         self.container_name = container_name
-        self.keep_vdbs = keep_vdbs
+        self.delete_vdbs = delete_vdbs
+        self.keep_vdbs = not(delete_vdbs)
         try:
             dx_logging.print_info(f"Running dxi container delete")
             self._execute_operation(self.__delete_container_helper)
@@ -733,3 +737,117 @@ class DXIContainer(DXIBase):
                 f"{self.container_name}. The error was:\n{err}"
             )
             self.failures[0] = True
+
+    def enable(self, container_name):
+        """
+        :param container_name: Name of the SS Container
+        :type container_name: `str`
+        :return: True if execution succeeds, else False
+        :rtype: `bool`
+        """
+        self.container_name = container_name
+        try:
+            dx_logging.print_info(f"Running dxi container enable")
+            self._execute_operation(self.__enable_container_helper)
+            return True
+        except Exception:
+            return False
+
+    @run_async
+    def __enable_container_helper(self, engine_ref, dlpx_obj, single_thread):
+        """
+        :param engine_ref: Dictionary of engines
+        :type engine_ref: `dict`
+        :param dlpx_obj: DDP session object
+        :type dlpx_obj: `lib.GetSession.GetSession`
+        :param single_thread: True - run single threaded, False -
+            run multi-thread
+        :type single_thread: `bool`
+        :return: True if execution succeeds, else False
+        :rtype: `bool`
+        """
+        try:
+            dlpx_obj = self._initialize_session()
+            self._setup_dlpx_session(dlpx_obj, engine_ref)
+            with dlpx_obj.job_mode(single_thread):
+                selfservice.container.enable(
+                    dlpx_obj.server_session,
+                    get_references.find_obj_by_name(
+                        dlpx_obj.server_session,
+                        selfservice.container,
+                        self.container_name,
+                    ).reference
+                )
+                self._add_last_job_to_track(dlpx_obj)
+                run_job.track_running_jobs(
+                    engine_ref,
+                    dlpx_obj,
+                    poll=self.poll,
+                    failures=self.failures,
+                )
+        except DXIException as err:
+            dx_logging.print_exception(err)
+            self.failures[0] = True
+        except (Exception, BaseException) as err:
+            dx_logging.print_exception(
+                f"Container {self.container_name} was not enabled."
+                f"The error was:\n{str(err)}"
+            )
+            self.failures[0] = True
+
+    def disable(self, container_name):
+        """
+        :param container_name: Name of the SS Container
+        :type container_name: `str`
+        :return: True if execution succeeds, else False
+        :rtype: `bool`
+        """
+        self.container_name = container_name
+        try:
+            dx_logging.print_info(f"Running dxi container disable")
+            self._execute_operation(self.__disable_container_helper)
+            return True
+        except Exception:
+            return False
+
+    @run_async
+    def __disable_container_helper(self, engine_ref, dlpx_obj, single_thread):
+        """
+        :param engine_ref: Dictionary of engines
+        :type engine_ref: `dict`
+        :param dlpx_obj: DDP session object
+        :type dlpx_obj: `lib.GetSession.GetSession`
+        :param single_thread: True - run single threaded, False -
+            run multi-thread
+        :type single_thread: `bool`
+        :return: True if execution succeeds, else False
+        :rtype: `bool`
+        """
+        try:
+            dlpx_obj = self._initialize_session()
+            self._setup_dlpx_session(dlpx_obj, engine_ref)
+            with dlpx_obj.job_mode(single_thread):
+                selfservice.container.disable(
+                    dlpx_obj.server_session,
+                    get_references.find_obj_by_name(
+                        dlpx_obj.server_session,
+                        selfservice.container,
+                        self.container_name,
+                    ).reference
+                )
+                self._add_last_job_to_track(dlpx_obj)
+                run_job.track_running_jobs(
+                    engine_ref,
+                    dlpx_obj,
+                    poll=self.poll,
+                    failures=self.failures,
+                )
+        except DXIException as err:
+            dx_logging.print_exception(err)
+            self.failures[0] = True
+        except (Exception, BaseException) as err:
+            dx_logging.print_exception(
+                f"Container {self.container_name} was not disabled."
+                f"The error was:\n{str(err)}"
+            )
+            self.failures[0] = True
