@@ -51,7 +51,7 @@ class DXIEnvironment(DXIBase):
 
     def __init__(
         self,
-        engine=None,
+        engine=EnvironmentConstants.ENGINE_ID,
         log_file_path=EnvironmentConstants.LOG_FILE_PATH,
         config_file=EnvironmentConstants.CONFIG,
         poll=EnvironmentConstants.POLL,
@@ -183,7 +183,7 @@ class DXIEnvironment(DXIBase):
         try:
             self._environment_execution_helper()
             dx_logging.print_debug("End of Execution")
-            return True
+            return self.environment_list
         except Exception as err:
             dx_logging.print_exception(
                 f"An Error was encountered during "
@@ -415,6 +415,7 @@ class DXIEnvironment(DXIBase):
         :type dlpx_obj: lib.GetSession.GetSession object
         """
         all_envs = environment.get_all(dlpx_obj.server_session)
+        self.environment_list = []
         if not all_envs:
             dx_logging.print_info(
                 f"There are no environments on "
@@ -480,6 +481,7 @@ class DXIEnvironment(DXIBase):
                 tablefmt="grid",
             )
         )
+        self.environment_list = env_list
         return env_list
 
     def _delete_env(self, dlpx_obj):
@@ -674,7 +676,8 @@ class DXIEnvironment(DXIBase):
         try:
             with dlpx_obj.job_mode(single_thread):
                 if self.action == EnvironmentOps.LIST:
-                    self._list_env(dlpx_obj)
+                    env_list = self._list_env(dlpx_obj)
+                    return env_list
                 elif self.action == EnvironmentOps.ADD:
                     if self.env_type.lower() == EnvironmentTypes.WIN.value:
                         self._add_windows_env(dlpx_obj)
