@@ -23,6 +23,7 @@ from dxi._lib import get_references as ref
 from dxi._lib import run_job
 from dxi._lib.dxi_constants import TemplateOps
 from dxi._lib.run_async import run_async
+from dxi._lib.util import DXIConfigConstantsHelper
 from dxi.dxi_tool_base import DXIBase
 from tabulate import tabulate
 
@@ -34,8 +35,8 @@ class DXITemplateConstants(object):
 
     SINGLE_THREAD = False
     POLL = 20
-    CONFIG = "../../dxi-data/config/dxtools.conf"
-    LOG_FILE_PATH = "../../dxi-data/logs/"
+    CONFIG = DXIConfigConstantsHelper().get_config()
+    LOG_FILE_PATH = DXIConfigConstantsHelper().get_logdir()
     ENGINE_ID = "default"
     PARALLEL = 5
     ACTION = None
@@ -91,7 +92,7 @@ class DXITemplate(DXIBase):
         """
         List all templates on an engine
         """
-        self.action = TemplateOps.CREATE
+        self.action = TemplateOps.LIST
         try:
             self._execute_operation(self._list_template_helper)
             return True
@@ -126,7 +127,7 @@ class DXITemplate(DXIBase):
         :param template_name: Name of the template to delete
         :type template_name: str
         """
-        self.action = TemplateOps.CREATE
+        self.action = TemplateOps.DELETE
         self.template_name = template_name
         try:
             self._execute_operation(self._delete_template_helper)
@@ -186,21 +187,20 @@ class DXITemplate(DXIBase):
                                 )
                             )
                         )
-                self._add_last_job_to_track(dlpx_obj)
-                run_job.track_running_jobs(
-                    engine_ref,
-                    dlpx_obj,
-                    poll=self.poll,
-                    failures=self.failures,
-                )
-            print("\n")
-            print(
-                tabulate(
-                    print_list,
-                    headers=DXITemplateConstants.LIST_HEADER,
-                    tablefmt="grid",
-                )
-            )
+                    self._add_last_job_to_track(dlpx_obj)
+                    run_job.track_running_jobs(
+                        engine_ref,
+                        dlpx_obj,
+                        poll=self.poll,
+                        failures=self.failures,
+                    )
+                    print(
+                        tabulate(
+                            print_list,
+                            headers=DXITemplateConstants.LIST_HEADER,
+                            tablefmt="grid",
+                        )
+                    )
             return container_list
         except (
             dxe.DlpxException,
